@@ -30,7 +30,8 @@ class Boxplot(Vis):
     """
     def __init__(self, df: pd.DataFrame, x: object, y: object, title='', xlabel='', ylabel='', box_colors=None,
                  hue=None, order=None, hue_order=None, showfliers=False, add_dots=False, add_stats=True,
-                 stat_method='Mann-Whitney', box_pairs=None, figsize=(1.5, 1.5), title_font_size=8, label_font_size=6, title_font_weight=700):
+                 stat_method='Mann-Whitney', box_pairs=None, figsize=(3, 3), title_font_size=12, label_font_size=8,
+                 title_font_weight=700, config=None):
         super().__init__(df, figsize=figsize, title_font_size=title_font_size, label_font_size=label_font_size,
                          title_font_weight=title_font_weight)
         self.df = df
@@ -49,6 +50,8 @@ class Boxplot(Vis):
         self.xlabel = xlabel
         self.ylabel = ylabel
         self.box_colors = box_colors
+        if config:
+            self.load_style(config)
 
     def format_data_for_boxplot(self, df: pd.DataFrame, conditions: list, filter_column=None, filter_values=None):
         condition_dict = defaultdict(list)
@@ -113,7 +116,7 @@ class Boxplot(Vis):
         ax = sns.boxplot(data=vis_df, x=x, y=y, hue=hue, hue_order=hue_order, order=order, palette=self.palette,
                          showfliers=self.showfliers)
         if self.add_dots:
-            ax = sns.swarmplot(data=vis_df, x=x, y=y, hue_order=hue_order, order=order, color='.2')
+            ax = sns.swarmplot(data=vis_df, x=x, y=y, hue_order=hue_order, order=order, alpha=0.5, color='.2')
         if self.add_stats:
             # Add all pairs in the order if the box pairs is none
             if box_pairs is None:
@@ -132,15 +135,21 @@ class Boxplot(Vis):
                                 box_pairs=box_pairs,
                                 test=self.stat_method, text_format='star', loc='inside', verbose=2)
 
-        ax.set_xticklabels(ax.get_xticklabels(), rotation=45, horizontalalignment='right')
-        if legend:
-            plt.legend(bbox_to_anchor=(1.05, 1), loc=2, borderaxespad=0.,  fontsize=self.label_font_size)
-        ax.tick_params(labelsize=self.label_font_size)
-        self.add_labels()
+        ax.set_xticklabels(ax.get_xticklabels(), rotation=45, horizontalalignment='right', weight = 'bold')
 
         # Check if the user supplied a list of colours for the boxes:
         if self.box_colors is not None:
             for i, b in enumerate(ax.artists):
                 b.set_facecolor(self.box_colors[i])
+
+        if legend and not self.box_colors:
+            plt.legend(order, bbox_to_anchor=(1.05, 1), loc=2, borderaxespad=0.,  fontsize=self.label_font_size)
+        elif legend and self.box_colors:
+            plt.legend(order, bbox_to_anchor=(1.05, 1), loc=2, borderaxespad=0.,
+                       fontsize=self.label_font_size)
+
+        ax.tick_params(labelsize=self.label_font_size)
+        self.add_labels()
+
         self.set_ax_params(ax)
         return ax
\ No newline at end of file
