@@ -43,9 +43,9 @@ class Vis:
 
     """
 
-    def __init__(self, df: pd.DataFrame, sciutil=None, cmap='seismic', sep='_', dpi=300,
+    def __init__(self, df: pd.DataFrame, sciutil=None, cmap='Purples', sep='_', dpi=300,
                  style='ticks', palette='pastel', opacity=0.8, default_colour="teal", figsize=(3, 3),
-                 title_font_size=8, label_font_size=6, title_font_weight=700, text_font_weight=700):
+                 title_font_size=12, label_font_size=8, title_font_weight=700, text_font_weight=700):
         self.sep = sep
         self.df = df
         self.columns = list(df.columns)
@@ -62,37 +62,74 @@ class Vis:
         self.title_font_size = title_font_size
         self.title_font_weight = title_font_weight
         self.text_font_weight = text_font_weight
+        self.axis_font_size = label_font_size
         self.palette = palette
         self.title = None
         self.xlabel = None
         self.ylabel = None
         self.cmap_str = cmap
-        self.labels = 'short'
-        self.palette = ['#483873', '#1BD8A6', '#B117B7', '#AAC7E2', '#FFC107', '#016957', '#9785C0',
+        self.labels = None
+        self.bins, self.cluster_rows, self.cluster_cols, self.line_width = None, None, None, None
+        self.col_colours, self.row_colours, self.vmin, self.vmax, self.x_tick_labels = None, None, None, None, None
+        self.min_x, self.min_y, self.max_x, self.max_y = None, None, None, None
+        self.add_legend, self.zlabel, self.colour = None, None, None
+        self.hue, self.add_dots, self.add_stats, self.stat_method = None, None, None, None
+        self.palette = palette if palette else ['#AAC7E2', '#FFC107', '#016957', '#9785C0',
              '#D09139', '#338A03', '#FF69A1', '#5930B1', '#FFE884', '#35B567', '#1E88E5',
-             '#ACAD60', '#A2FFB4', '#B618F5', '#854A9C']
+             '#ACAD60', '#A2FFB4', '#B68F5', '#854A9C']
+        if isinstance(self.palette, str):
+            self.palette = sns.color_palette(self.palette)
+
         plt.rcParams['svg.fonttype'] = 'none'  # Ensure text is saved as text
         plt.rcParams['figure.figsize'] = self.figsize
-        sns.set(rc={'figure.figsize': self.figsize, 'font.family': 'sans-serif',
-                    'font.sans-serif': 'Arial', 'font.size': label_font_size}, style=self.style)
+        self.font_family = 'sans-serif'
+        self.font = 'Arial'
+        sns.set(rc={'figure.figsize': self.figsize, 'font.family': self.font_family,
+                    'font.sans-serif': self.font, 'font.size': label_font_size}, style=self.style)
 
     def load_style(self, style_dict):
         """ Load a style from a dict. """
         self.default_colour = style_dict.get('default_colour') or self.default_colour
         self.label_font_size = style_dict.get('label_font_size') or self.label_font_size
+        self.axis_font_size = style_dict.get('axis_font_size') or self.axis_font_size
         self.title_font_size = style_dict.get('title_font_size') or self.title_font_size
         self.title_font_weight = style_dict.get('title_font_weight') or self.title_font_weight
         self.text_font_weight = style_dict.get('text_font_weight') or self.text_font_weight
         self.palette = style_dict.get('palette') or self.palette
         self.figsize = style_dict.get('figsize') or self.figsize
         plt.rcParams['figure.figsize'] = self.figsize
-        sns.set(rc={'figure.figsize': self.figsize, 'font.family': 'sans-serif',
-                    'font.sans-serif': 'Arial', 'font.size': self.label_font_size}, style=self.style)
+        self.font_family = self.font_family or 'sans-serif'
+        self.font = self.font or 'Arial'
+        sns.set(rc={'figure.figsize': self.figsize, 'font.family': self.font_family,
+                    'font.sans-serif': self.font, 'font.size': self.label_font_size}, style=self.style)
+        plt.rcParams['font.family'] = self.font_family
+        plt.rcParams['font.sans-serif'] = self.font
         self.cmap_str = style_dict.get('cmap') or self.cmap_str
         self.style = style_dict.get('style') or self.style
         self.cmap = ListedColormap(sns.color_palette(self.cmap_str))
         self.opacity = style_dict.get('opacity') or self.opacity
         self.labels = style_dict.get('labels') or self.labels
+        self.bins = style_dict.get('bins') or self.bins
+        self.cluster_rows = style_dict.get('cluster_rows') or self.cluster_rows
+        self.cluster_cols = style_dict.get('cluster_cols') or self.cluster_cols
+        self.line_width = style_dict.get('line_width') or self.line_width
+        self.vmin = style_dict.get('vmin') or self.vmin
+        self.vmax = style_dict.get('vmax') or self.vmax
+        self.col_colours = style_dict.get('col_colours') or self.col_colours
+        self.row_colours = style_dict.get('row_colours') or self.row_colours
+        self.x_tick_labels = style_dict.get('x_tick_labels') or self.x_tick_labels
+        self.min_x = style_dict.get('min_x') or self.min_x
+        self.min_y = style_dict.get('min_y') or self.min_y
+        self.max_x = style_dict.get('max_x') or self.max_x
+        self.max_y = style_dict.get('max_y') or self.max_y
+        self.add_legend = style_dict.get('add_legend') or self.add_legend
+        self.zlabel = style_dict.get('zlabel') or self.zlabel
+        self.colour = style_dict.get('colour') or self.colour
+        self.add_dots = style_dict.get('add_dots') or self.add_dots
+        self.add_stats = style_dict.get('add_stats') or self.add_stats
+        self.stat_method = style_dict.get('stat_method') or self.stat_method
+        self.hue = style_dict.get('hue') or self.hue
+        self.s = style_dict.get('s') or 10
 
     def set_palette(self, palette):
         self.palette = palette
@@ -231,21 +268,6 @@ class Vis:
         ax.spines['top'].set_linewidth(0)
         ax.spines['left'].set_linewidth(0.5)
         ax.spines['right'].set_linewidth(0)
-        ax.tick_params(labelsize=self.label_font_size)
+        ax.tick_params(labelsize=self.axis_font_size)
         ax.tick_params(axis='x', which='major', pad=2.0)
-        ax.tick_params(axis='y', which='major', pad=2.0)
-        # Make sure if the labels are very long they wrap
-        labels = [str(item.get_text()).replace('_', ' ') for item in ax.get_xticklabels()]
-        if self.labels == 'wrap':
-            labels_short = ['\n'.join(wrap(l, 20)) for l in labels]
-        elif self.labels == 'short':
-            labels_short = []
-            for l in labels:
-                if len(l) < 15:
-                    labels_short.append(l)
-                else:
-                    labels_short.append(f'{l[:15]}...')
-        else:
-            labels_short = labels
-        if labels_short[0] != '':
-            ax.set_xticklabels(labels_short, weight=self.text_font_weight)
+        ax.tick_params(axis='y', which='major', pad=2.0)
\ No newline at end of file
